AnimationsOptions class

Constructors

AnimationsOptions({Duration zoom = const Duration(milliseconds: 500), Duration fitBound = const Duration(milliseconds: 500), Curve fadeInCurve = Curves.easeInCubic, Curve fadeOutCurve = Curves.easeInCubic, Curve clusterExpandCurve = Curves.easeInCubic, Curve clusterCollapseCurve = Curves.easeInCubic, Curve spiderifyCurve = Curves.fastOutSlowIn, Duration centerMarker = const Duration(milliseconds: 500), Duration spiderfy = const Duration(milliseconds: 500), Curve fitBoundCurves = Curves.fastOutSlowIn, Curve centerMarkerCurves = Curves.fastOutSlowIn})
const

Properties

centerMarker Duration
final
centerMarkerCurves Curve
final
clusterCollapseCurve Curve
final
clusterExpandCurve Curve
final
fadeInCurve Curve
final
fadeOutCurve Curve
final
fitBound Duration
final
fitBoundCurves Curve
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spiderfy Duration
final
spiderifyCurve Curve
final
zoom Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited